mysql.util._c_only

Package mysql :: Package util :: Module _c_only |
[hide private]
[frames] | no frames]

# Module _c_only

Internal module of C helper functions.

Functions | [hide private]
`` | escape(...) Escape a string suitable for values in MySQL statements.

Variables | [hide private]
`` | __version__ = `'$Revision: 1.3 $'`

Function Details | [hide private]

### escape(...) |
Escape a string suitable for values in MySQL statements. Parameters: `value` - A string to escape. Returns: Returns an escaped string with enclosing single quotes.

Variables Details | [hide private]

    ### __version__ Value:
        '$Revision: 1.3 $'